@@ -23,11 +23,12 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "camel-stub.h"
 
 #include <camel/camel-exception.h>
 #include <camel/camel-operation.h>
-#include <camel/camel-i18n.h>
 
 #include <errno.h>
 #include <string.h>
@@ -317,7 +318,7 @@ stub_send_internal (CamelStub *stub, CamelException *ex, gboolean oneway,
 		}		
 		
 		default:
-			g_assert_not_reached ();
+			g_critical ("%s: Uncaught case (%d)", G_STRLOC, argtype);
 			break;
 		}
 	}
@@ -455,7 +456,7 @@ stub_send_internal (CamelStub *stub, CamelException *ex, gboolean oneway,
 				}
 
 				default:
-					g_assert_not_reached ();
+					g_critical ("%s: Uncaught case (%d)", G_STRLOC, argtype);
 					status = -1;
 					break;
 				}
@@ -468,7 +469,7 @@ stub_send_internal (CamelStub *stub, CamelException *ex, gboolean oneway,
 		}
 
 		default:
-			g_assert_not_reached ();
+			g_critical ("%s: Uncaught case (%d)", G_STRLOC, retval);
 			break;
 		}
 	} while (retval != CAMEL_STUB_RETVAL_OK);
